Learn R Programming

saemix (version 1.2)

SaemixModel-class: Class "SaemixModel"

Description

An object of the SaemixModel class, representing a non-linear mixed-effect model structure, used by the SAEM algorithm.

Arguments

Objects from the Class

An object of the SaemixModel class can be created by using the function saemixModel

Slots

model:

function used to compute the structural model. The function should return a vector of predicted values given a matrix of individual parameters, a vector of indices specifying which records belong to a given individual, and a matrix of dependent variables (see examples).

description:

model description (optional) as a character string

psi0:

a matrix with a number of columns equal to the number of parameters in the model, and one (when no covariates are available) or two (when covariates enter the model) giving the initial estimates for the fixed effects. The column names of the matrix should be the names of the parameters in the model, and will be used in the plots and the summaries

transform.par:

the distribution for each parameter (0=normal, 1=log-normal, 2=probit, 3=logit). Defaults to a vector of 1s (all parameters have a log-normal distribution)

fixed.estim:

whether parameters should be estimated (1) or fixed to their initial estimate (0). Defaults to a vector of 1s

error.model:

name of the residual error model

covariate.model:

a matrix giving the covariate model. Defaults to no covariate in the model (empty matrix)

betaest.model:

a matrix giving the effects model (internal)

covariance.model:

a square matrix of size equal to the number of parameters in the model, giving the variance-covariance matrix of the model: 1s correspond to estimated variances (in the diagonal) or covariances (off-diagonal elements). Defaults to the identity matrix

omega.init:

a square matrix of size equal to the number of parameters in the model, giving the initial estimate for the variance-covariance matrix of the model. Defaults to the identity matrix

error.init:

a vector of size 2 giving the initial value of a and b in the error model. Defaults to 1 for each estimated parameter in the error model

nb.parameters:

number of parameters

name.modpar:

names of the model parameters

name.fixed:

names of the fixed effects estimated in the model

name.random:

names of the random effects estimated in the model

name.res:

names of the parameters of the residual error model

name.predictors:

names of the predictors (X)

name.X:

name of the predictor used in graphs

name.response:

name of the response (Y)

name.cov:

name of the covariates

indx.fix:

index of estimated fixed effects (internal)

indx.cov:

index of estimated fixed effects associated with covariate effects (internal)

indx.omega:

index of estimated random effects (internal)

indx.res:

index of parameters of the residual error model (internal)

Mcovariates:

matrix of the covariates (internal)

Methods

[<-

signature(x = "SaemixModel"): replace elements of object

[

signature(x = "SaemixModel"): access elements of object

initialize

signature(.Object = "SaemixModel"): internal function to initialise object, not to be used

plot

signature(x = "SaemixModel"): plot results (see saemix.plot.data

print

signature(x = "SaemixModel"): prints details about the object

showall

signature(object = "SaemixModel"): prints an extensive summary of the object

show

signature(object = "SaemixModel"): prints a short summary of the object

summary

signature(object = "SaemixModel"): summary of the model

References

Kuhn E, Lavielle M. Maximum likelihood estimation in nonlinear mixed effects models. Computational Statistics and Data Analysis 49, 4 (2005), 1020-1038.

Comets E, Lavenu A, Lavielle M. SAEMIX, an R version of the SAEM algorithm. 20th meeting of the Population Approach Group in Europe, Athens, Greece (2011), Abstr 2173.

See Also

SaemixData,saemixModel, saemixControl,saemix

Examples

Run this code
# NOT RUN {
showClass("SaemixModel")
# }

Run the code above in your browser using DataLab