An object of the SaemixObject class, storing the results obtained by a call to the SAEM algorithm
Objects are created by a call saemix().
data:Object of class "SaemixData" an object of the SaemixData class, representing a longitudinal data structure, used by the SAEM algorithm. See SaemixData
model:Object of class "SaemixModel" an object of the SaemixModel class, representing the structure a non-linear mixed effect model, used by the SAEM algorithm. See SaemixModel
results:Object of class "SaemixRes" ~~
rep.data:Object of class "SaemixRepData" (internal use only) the data part, replicated a number of times equal to the number of chains used in the SAEM algorithm (see documentation for details). Not intended to be accessed to directly by the user.
sim.data:Object of class "SaemixSimData" (internal use only) data simulated according to the design in data, with the model in model and the parameters estimated by the SAEM algorithm, after a call to simul.saemix (see documentation for details). Not intended to be accessed to directly by the user.
options:Object of class "list" a list of options containing variables controlling the algorithm
prefs:Object of class "list" a list of graphical preferences applied to plots
signature(x = "SaemixObject"): replace elements of object
signature(x = "SaemixObject"): access elements of object
signature(.Object = "SaemixObject"): internal function to initialise object, not to be used
signature(x = "SaemixObject"): plot results (see saemix.plot.data
signature(object = "SaemixObject"): compute model predictions
signature(x = "SaemixObject"): prints details about the object
signature(object = "SaemixObject"): prints an extensive summary of the object
signature(object = "SaemixObject"): prints a short summary of the object
signature(object = "SaemixObject"): summary of the results
signature(object = "SaemixObject"): extracts coefficients. Returns a list with components fixed (estimated fixed effects), population (population parameter estimates, including covariate effects: a list with two components map and cond), individual (individual parameter estimates: a list with two components map and cond). For population and individual, the map component of the list gives the MAP estimates (the mode of the distribution) while the cond component gives the conditional mean estimates. Some components may be missing (eg MAP estimates) if they have not been computed during or after the fit.
Details of the algorithm can be found in the pdf file accompanying the package.
Kuhn E, Lavielle M. Maximum likelihood estimation in nonlinear mixed effects models. Computational Statistics and Data Analysis 49, 4 (2005), 1020-1038.
Comets E, Lavenu A, Lavielle M. SAEMIX, an R version of the SAEM algorithm. 20th meeting of the Population Approach Group in Europe, Athens, Greece (2011), Abstr 2173.
SaemixData,SaemixModel, saemixControl,saemix,plot.saemix, saemix.plot.data
# NOT RUN {
showClass("SaemixObject")
# }
Run the code above in your browser using DataLab