Learn R Programming

saemix (version 1.2)

plot-methods: Methods for Function plot

Description

Methods for function plot

Arguments

Methods

signature(x = "ANY")

default plot function ?

signature(x = "SaemixData")

Plots the data. Defaults to a spaghetti plot of response versus predictor, with lines joining the data for one individual.

signature(x = "SaemixModel")

Plots prediction of the model

signature(x = "SaemixObject")

This method gives access to a number of plots that can be performed on a SaemixObject

signature(x = "SaemixSimData")

Plots simulated datasets