Learn R Programming

saemix (version 0.96.1)

saemix.plot.setoptions: Function setting the default options for the plots in SAEM

Description

This function can be used to create a list containing the default options and arguments used by the plot functions.

Usage

saemix.plot.setoptions(saemixObject)

Arguments

saemixObject
an object returned by the saemix function

Value

  • A list containing the options set at their default value. This list can be stored in an object and its elements modified to provide suitable graphs.

Details

A description of the options set via this list is provided in the PDF documentation. [object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]

References

Kuhn, E., and Lavielle, M. Maximum likelihood estimation in nonlinear mixed effects models. Computational Statistics and Data Analysis 49, 4 (2005), 1020-1038.

Monolix32_UsersGuide.pdf (http://software.monolix.org/sdoms/software/)

See Also

SaemixObject,saemix, saemix.plot.data, saemix.plot.convergence, saemix.plot.llis, saemix.plot.randeff, saemix.plot.obsvspred, saemix.plot.fits, saemix.plot.parcov, saemix.plot.distpsi, saemix.plot.scatterresiduals, saemix.plot.vpc

Examples

Run this code
# Theophylline example, after a call to fit.saemix (see examples)
# Not run
# sopt<-saemix.plot.setoptions(saemix.fit)
# sopt$ask<-TRUE

Run the code above in your browser using DataLab