List containing the variables relative to the optimisation algorithm. All these elements are optional and will be set to default values when running the algorithm if they are not specified by the user.
saemixControl(algorithms = c(1, 1, 1), nbiter.saemix = c(300, 100),
nb.chains = 1, fix.seed = TRUE, seed = 23456, nmc.is = 5000, nu.is = 4,
print.is = FALSE, nbdisplay = 100, displayProgress = TRUE, nbiter.burn = 5,
nbiter.mcmc = c(2, 2, 2), proba.mcmc = 0.4, stepsize.rw = 0.4, rw.init = 0.5,
alpha.sa = 0.97, nnodes.gq = 12, nsd.gq = 4, maxim.maxiter = 100,
nb.sim = 1000, nb.simpred = 100, ipar.lmcmc = 50, ipar.rmcmc = 0.05,
print = TRUE, save = TRUE, save.graphs = TRUE, directory = "newdir",
warnings = FALSE)a vector of 1s specifying which algorithms are to be run. Defaults to c(1,1,1) (respectively estimation of the individual parameters (MAP estimates), estimation of the Fisher Information Matrix and log-likelihood by linearisation, and estimation of the log-likelihood by importance sampling)
nb of iterations in each step (a vector containing 2 elements)
nb of chains to be run in parallel in the MCMC algorithm. Defaults to 1.
nb of iterations for burning
nb of iterations in each kernel during the MCMC step
probability of acceptance
stepsize for kernels q2 and q3. Defaults to 0.4
initial variance parameters for kernels. Defaults to 0.5
parameter controlling cooling in the Simulated Annealing algorithm. Defaults to 0.97
TRUE (default) to use a fixed seed for the random number generator. When FALSE, the random number generator is initialised using a new seed, created from the current time. Hence, different sessions started at (sufficiently) different times will give different simulation results. The seed is stored in the element seed of the options list.
seed for the random number generator. Defaults to 123456
nb of samples used when computing the likelihood through importance sampling
number of degrees of freedom of the Student distribution used for the estimation of the log-likelihood by Importance Sampling. Defaults to 4
when TRUE, a plot of the likelihood as a function of the number of MCMC samples when computing the likelihood through importance sampling is produced and updated every 500 samples. Defaults to FALSE
nb of iterations after which to display progress
when TRUE, the convergence plots are plotted after every nbdisplay iteration, and a dot is written in the terminal window to indicate progress. When FALSE, plots are not shown and the algorithm runs silently. Defaults to TRUE
number of nodes to use for the Gaussian quadrature when computing the likelihood with this method (defaults to 12)
span (in SD) over which to integrate when computing the likelihood by Gaussian quadrature. Defaults to 4 (eg 4 times the SD)
Maximum number of iterations to use when maximising the fixed effects in the algorithm. Defaults to 100
number of simulations to perform to produce the VPC plots or compute npde. Defaults to 1000
number of simulations used to compute mean predictions (ypred element), taken as a random sample within the nb.sim simulations used for npde
number of iterations required to assume convergence for the conditional estimates. Defaults to 50
confidence interval for the conditional mean and variance. Defaults to 0.95
whether the results of the fit should be printed out. Defaults to TRUE
whether the results of the fit should be saved to a file. Defaults to TRUE
whether diagnostic graphs and individual graphs should be saved to files. Defaults to TRUE
the directory in which to save the results. Defaults to "newdir" in the current directory
whether warnings should be output during the fit. Defaults to FALSE
All the variables are optional and will be set to their default value when running saemix.
The function saemix returns an object with an element options containing the options used for the algorithm, with defaults set for elements which have not been specified by the user.
These elements are used in subsequent functions and are not meant to be used directly.
Kuhn E, Lavielle M. Maximum likelihood estimation in nonlinear mixed effects models. Computational Statistics and Data Analysis 49, 4 (2005), 1020-1038.
Comets E, Lavenu A, Lavielle M. SAEMIX, an R version of the SAEM algorithm. 20th meeting of the Population Approach Group in Europe, Athens, Greece (2011), Abstr 2173.
# NOT RUN {
# All default options
saemix.options<-saemixControl()
# All default options, changing seed
saemix.options<-saemixControl(seed=632545)
# }
Run the code above in your browser using DataLab