Learn R Programming

saemix (version 0.96.1)

testnpde: Tests for normalised prediction distribution errors

Description

Performs tests for the normalised prediction distribution errors returned by npde

Usage

testnpde(npde)

Arguments

npde
the vector of prediction distribution errors

Value

  • a list containing 4 components:
  • Wilcoxon test of mean=0compares the mean of the npde to 0 using a Wilcoxon test
  • variance testcompares the variance of the npde to 1 using a Fisher test
  • SW test of normalitycompares the npde to the normal distribution using a Shapiro-Wilks test
  • global testan adjusted p-value corresponding to the minimum of the 3 previous p-values multiplied by the number of tests (3), or 1 if this p-value is larger than 1.

Details

Given a vector of normalised prediction distribution errors (npde), this function compares the npde to the standardised normal distribution N(0,1) using a Wilcoxon test of the mean, a Fisher test of the variance, and a Shapiro-Wilks test for normality. A global test is also reported. The helper functions kurtosis and skewness are called to compute the kurtosis and skewness of the distribution of the npde.

References

K. Brendel, E. Comets, C. Laffont, C. Laveille, and F. Mentr'e. Metrics for external model evaluation with an application to the population pharmacokinetics of gliclazide. Pharmaceutical Research, 23:2036--49, 2006.

See Also

saemix, saemix.plot.npde