Methods for function plot
signature(x = "ANY")default plot function ?
signature(x = "SaemixData")Plots the data. Defaults to a spaghetti plot of response versus predictor, with lines joining the data for one individual.
signature(x = "SaemixModel")Plots prediction of the model
signature(x = "SaemixObject")This method gives access to a number of plots that can be performed on a SaemixObject
signature(x = "SaemixSimData")Plots simulated datasets